@@ -1,5 +1,5 @@
 #  GNU Mailutils -- a suite of utilities for electronic mail
-#  Copyright (C) 2009, 2010 Free Software Foundation, Inc.
+#  Copyright (C) 2009-2025 Free Software Foundation, Inc.
 #
 #  GNU Mailutils is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -12,9 +12,7 @@
 #  GNU General Public License for more details.
 #
 #  You should have received a copy of the GNU General Public License
-#  along with GNU Mailutils; if not, write to the Free Software
-#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-#  MA 02110-1301 USA
+#  along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. 
 
 import sys
 from mailutils import address
@@ -28,27 +26,27 @@ def parse (str):
         addr = address.Address (str)
 
         count = addr.get_count ()
-        print "%s => count %d" % (addr, len (addr))
+        print("%s => count %d" % (addr, len (addr)))
 
         for no in range (1, count + 1):
             isgroup = addr.is_group (no)
-            print "%d " % no,
+            print("%d " % no, end="")
 
             if isgroup:
-                print "group <%s>" % addr.get_personal (no)
+                print("group <%s>" % addr.get_personal (no))
             else:
-                print "email <%s>" % addr.get_email (no)
+                print("email <%s>" % addr.get_email (no))
 
             if not isgroup:
-                print "   personal <%s>" % addr.get_personal (no)
+                print("   personal <%s>" % addr.get_personal (no))
 
-            print "   comments <%s>" % addr.get_comments (no)
-            print "   local-part <%s> domain <%s>" % (addr.get_local_part (no),
-                                                      addr.get_domain (no))
-        print "   route <%s>" % addr.get_route (no)
-    except AddressError, e:
-        print e
-    print
+            print("   comments <%s>" % addr.get_comments (no))
+            print("   local-part <%s> domain <%s>" % (addr.get_local_part (no),
+                                                      addr.get_domain (no)))
+        print("   route <%s>" % addr.get_route (no))
+    except AddressError as e:
+        print(e)
+    print("")
 
 def parseinput ():
     try:
