@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2020 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -48,7 +48,8 @@ imap4d_login (struct imap4d_session *session,
 
   if (auth_data == NULL)
     {
-      mu_diag_output (MU_DIAG_INFO, _("user `%s' nonexistent"), username);
+      mu_diag_output (MU_DIAG_INFO, _("user %s nonexistent"),
+		      mu_quotename (username));
       return io_completion_response (command, RESP_NO, 
                                      "User name or passwd rejected");
     }
