@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2005-2020 Free Software Foundation, Inc.
+   Copyright (C) 2005-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -45,6 +45,7 @@
 #include <mailutils/cli.h>
 #include <mailutils/stream.h>
 #include <mailutils/stdstream.h>
+#include <mailutils/cstr.h>
 
 #ifdef ENABLE_RADIUS
 
@@ -105,7 +106,8 @@ cb_request (void *data, mu_config_value_t *val)
   if (mu_wordsplit (val->v.string, &ws,
 		    MU_WRDSF_DEFFLAGS|MU_WRDSF_DELIM|MU_WRDSF_RETURN_DELIMS))
     {
-      mu_error (_("cannot parse input `%s': %s"), val->v.string,
+      mu_error (_("cannot parse input %s: %s"),
+		mu_quotename (val->v.string),
 		mu_wordsplit_strerror (&ws));
       return 1;
     }
@@ -145,7 +147,8 @@ cb_request (void *data, mu_config_value_t *val)
 				   ws.ws_wordv[i]);
 	  if (!pair)
 	    {
-	      mu_error (_("cannot create radius A/V pair `%s'"), name);
+	      mu_error (_("cannot create radius A/V pair %s"),
+			mu_quotename (name));
 	      state = state_err;
 	    }
 	  else
@@ -158,7 +161,7 @@ cb_request (void *data, mu_config_value_t *val)
 	case state_delim:
 	  if (strcmp (ws.ws_wordv[i], ","))
 	    {
-	      mu_error (_("expected `,' but found `%s'"), ws.ws_wordv[i]);
+	      mu_error (_("expected ',' but found '%s'"), ws.ws_wordv[i]);
 	      state = state_err;
 	    }
 	  else
@@ -300,11 +303,11 @@ _expand_query (const char *query, const char *ustr, const char *passwd)
     {
       if (rc == MU_ERR_FAILURE)
 	{
-	  mu_error (_("cannot expand line `%s': %s"), query, ret);
+	  mu_error (_("cannot expand line %s: %s"), mu_quotename (query), ret);
 	  free (ret);
 	}
       else
-	mu_error (_("cannot expand line `%s': %s"), query, mu_strerror (rc));
+	mu_error (_("cannot expand line %s: %s"), mu_quotename (query), mu_strerror (rc));
       return NULL;
     }
   
@@ -377,7 +380,8 @@ decode_reply (grad_request_t *reply, const char *user_name, char *password,
     uid = p->avp_lvalue;
   else
     {
-      mu_error (_("radius server did not return UID for `%s'"),  user_name);
+      mu_error (_("radius server did not return UID for %s"),
+		mu_quotename (user_name));
       return -1;
     }
 
@@ -386,7 +390,8 @@ decode_reply (grad_request_t *reply, const char *user_name, char *password,
     gid = p->avp_lvalue;
   else
     {
-      mu_error (_("radius server did not return GID for `%s'"),  user_name);
+      mu_error (_("radius server did not return GID for %s"),
+		mu_quotename (user_name));
       return -1;
     }
 
