@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2024 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -51,8 +51,8 @@ append_to_mailbox (mu_url_t url, msgset_t *msglist, int mark,
   mu_mailbox_attach_ticket (mbx);
   if ((status = mu_mailbox_open (mbx, MU_STREAM_CREAT | MU_STREAM_APPEND)) != 0)
     {
-      mu_error (_("Cannot open mailbox %s: %s"), mu_url_to_string (url),
-		   mu_strerror (status));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_open",
+		       mu_url_to_string (url), status);
       mu_mailbox_destroy (&mbx);
       return 1;
     }
@@ -116,8 +116,8 @@ append_to_file (char const *filename, msgset_t *msglist, int mark,
 				  MU_STREAM_CREAT|MU_STREAM_APPEND);
   if (status)
     {
-      mu_error (_("Cannot open output file %s: %s"),
-		filename, mu_strerror (status));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_file_stream_create",
+		       filename, status);
       return 1;
     }
 
